Skip to main content

license PyPI version CircleCI Releases Language grade: Python Known Vulnerabilities

gears-cli

Simple cli that allows the send python code to RedisGears

Install

pip install gears-cli

Install latest code

pip install git+https://github.com/RedisGears/gears-cli.git

Usage

> gears-cli --help
Usage: gears-cli [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  export-requirements   Export requirements from RedisGears
  import-requirements   Import requirements to RedisGears
  install-requirements  Install give requirements
  run                   Run gears function


> gears-cli run --help
Usage: gears-cli run [OPTIONS] FILEPATH [EXTRA_ARGS]...

  Run gears function

Options:
  --host TEXT               Redis host to connect to
  --port INTEGER            Redis port to connect to
  --user TEXT               Redis acl user
  --password TEXT           Redis password
  --ssl BOOLEAN             Use ssl
  --ssl-password TEXT       Passphrase for ssl key
  --ssl-keyfile TEXT        Path to ssl key file
  --ssl-certfile TEXT       Path to ssl certificate file
  --ssl-ca-certs TEXT       Path to ssl ca certificate file
  --ssl-verify-ca BOOLEAN   Whether or not to us CA to verify certs
  --requirements TEXT       Path to requirements.txt file
  --help                    Show this message and exit.

> gears-cli export-requirements --help
Usage: gears-cli export-requirements [OPTIONS]

  Export requirements from RedisGears

Options:
  --host TEXT             Redis host to connect to
  --port INTEGER          Redis port to connect to
  --user TEXT             Redis acl user
  --password TEXT         Redis password
  --ssl BOOLEAN           Use ssl
  --ssl-password TEXT     Passphrase for ssl key
  --ssl-keyfile TEXT      Path to ssl key file
  --ssl-certfile TEXT     Path to ssl certificate file
  --ssl-ca-certs TEXT     Path to ssl ca certificate file
  --ssl-verify-ca BOOLEAN Whether or not to us CA to verify certs
  --save-directory TEXT   Directory for exported files
  --output-prefix TEXT    Prefix for the requirement zip file
  --registration-id TEXT  Regisrations ids to extract their requirements
  --requirement TEXT      Requirement to export
  --all                   Export all requirements
  --help                  Show this message and exit.

> gears-cli import-requirements --help
Usage: gears-cli import-requirements [OPTIONS] [REQUIREMENTS]...

  Import requirements to RedisGears

Options:
  --host TEXT               Redis host to connect to
  --port INTEGER            Redis port to connect to
  --user TEXT               Redis acl user
  --password TEXT           Redis password
  --ssl BOOLEAN             Use ssl
  --ssl-password TEXT       Passphrase for ssl key
  --ssl-keyfile TEXT        Path to ssl key file
  --ssl-certfile TEXT       Path to ssl certificate file
  --ssl-ca-certs TEXT       Path to ssl ca certificate file
  --ssl-verify-ca BOOLEAN   Whether or not to us CA to verify certs
  --requirements-path TEXT  Path of requirements directory containing
                            requirements zip files, could also be a zip file
                            contains more requirements zip files
  --all                     Import all requirements in zip file
  --bulk-size INTEGER       Max bulk size to send to redis in MB
  --help                    Show this message and exit.

> gears-cli install-requirements --help
Usage: gears-cli install-requirements [OPTIONS] [REQUIREMENTS]...

  Install give requirements

Options:
  --host TEXT               Redis host to connect to
  --port INTEGER            Redis port to connect to
  --user TEXT               Redis acl user
  --password TEXT           Redis password
  --ssl BOOLEAN             Use ssl
  --ssl-password TEXT       Passphrase for ssl key
  --ssl-keyfile TEXT        Path to ssl key file
  --ssl-certfile TEXT       Path to ssl certificate file
  --ssl-ca-certs TEXT       Path to ssl ca certificate file
  --ssl-verify-ca BOOLEAN   Whether or not to us CA to verify certs
  --requirements-file TEXT  Path to requirements.txt file
  --help                    Show this message and exit.

Metadata

Release files for gears-cli 1.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for gears-cli 1.2.0
File Size Uploaded
gears-cli-1.2.0.tar.gz 6.8 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for gears-cli 1.2.0
File Interpreter ABI Platform
gears_cli-1.2.0-py3-none-any.whl Python 3 none any Details

Total release size: 13.6 kB

Release files / gears-cli-1.2.0.tar.gz

Download URL gears-cli-1.2.0.tar.gz
Size 6.8 kB
Tags Source
SHA-256 checksum
How to use checksums
60dce6e44008a3be800bb33bb9a238410386bc8cbfa1552710ee051b289fe55b
BLAKE2b-256 checksum
How to use checksums
3ad73825a886884ec3012525b57a6cd1313acb4022334e3a4d90bdf066dd07c7
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.7.12 Linux/5.11.0-1028-azure

Release files / gears_cli-1.2.0-py3-none-any.whl

Download URL gears_cli-1.2.0-py3-none-any.whl
Size 6.8 kB
Tags Python 3
SHA-256 checksum
How to use checksums
79c816595ae619812e8132559e57df578e166552b642e7587e731e7913661827
BLAKE2b-256 checksum
How to use checksums
7daae1af736e858f10861148916ecef3217a6d8366921f0da33566a85e7519b8
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.7.12 Linux/5.11.0-1028-azure

Release history Release notifications | RSS feed

This release

1.2.0 This release

2 release files

1.1.3

2 release files

1.1.1

2 release files

1.1.0

2 release files

1.0.0

1 release file

0.1.0

1 release file

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page